@@ -153,7 +153,7 @@ impl App {
 			logfiles,
 		};
 		app.update_timelines(&Utc::now());
-		app.dash_state.update_summary_window(&mut app.monitors);
+		app.update_summary_window();
 
 		if !first_logfile.is_empty() {
 			app.dash_state.dash_node_focus = first_logfile.clone();
@@ -173,11 +173,11 @@ impl App {
 		}
 	}
 
-	pub fn update_chunk_store_stats(&mut self) {
-		for (_monitor_file, monitor) in self.monitors.iter_mut() {
-			monitor.update_chunk_store_fsstats();
-		}
-	}
+	// pub fn update_chunk_store_stats(&mut self) {
+	// 	for (_monitor_file, monitor) in self.monitors.iter_mut() {
+	// 		monitor.update_chunk_store_fsstats();
+	// 	}
+	// }
 
 	pub fn get_monitor_for_file_path(&mut self, logfile: &String) -> Option<&mut LogMonitor> {
 		let mut monitor_for_path = None;
@@ -251,6 +251,13 @@ impl App {
 			return;
 		}
 
+		if self.dash_state.main_view == DashViewMain::DashSummary {
+			if self.dash_state.summary_window_heading_selected < self.dash_state.summary_window_headings.items.len() - 1 {
+				self.dash_state.summary_window_heading_selected += 1;
+				self.update_summary_window();
+			}
+		}
+
 		let mut next_i = 0;
 		for (i, name) in self.dash_state.logfile_names.iter().enumerate() {
 			if name == &self.logfile_with_focus {
@@ -281,6 +288,13 @@ impl App {
 			return;
 		}
 
+		if self.dash_state.main_view == DashViewMain::DashSummary {
+			if self.dash_state.summary_window_heading_selected > 0 {
+				self.dash_state.summary_window_heading_selected -= 1;
+				self.update_summary_window();
+			}
+		}
+
 		let len = self.dash_state.logfile_names.len();
 		let mut previous_i = len - 1;
 		for (i, name) in self.dash_state.logfile_names.iter().enumerate() {
@@ -323,7 +337,7 @@ impl App {
 
 	pub fn handle_arrow(&mut self, is_down: bool) {
 		let list = match self.dash_state.main_view {
-			DashViewMain::DashSummary => { Some(&mut self.dash_state.summary_window_list) }
+			DashViewMain::DashSummary => { Some(&mut self.dash_state.summary_window_rows) }
 			DashViewMain::DashNode => {
 				if let Some(monitor) = self.get_monitor_with_focus() {
 					Some(&mut monitor.content)
@@ -350,17 +364,74 @@ impl App {
 
 	pub fn preserve_node_selection(&mut self) {
 		if self.dash_state.main_view == DashViewMain::DashSummary {
-			if let Some(selected_index) = self.dash_state.summary_window_list.state.selected() {
-				self.change_focus_to(selected_index);
+			if let Some(selected_index) = self.dash_state.summary_window_rows.state.selected() {
+				let selected_logfile = &self.dash_state.logfile_names_sorted[selected_index];
+				if let Some(node_index) = self.dash_state.logfile_names.iter().position(|s| s == selected_logfile.as_str()) {
+					self.change_focus_to(node_index);
+				}
 			}
 		} else if self.dash_state.main_view == DashViewMain::DashNode {
+			for index in 0..self.dash_state.logfile_names_sorted.len() {
+				if self.dash_state.logfile_names_sorted[index] == self.logfile_with_focus {
+					self.dash_state.summary_window_rows.state.select(Some(index));
+					break;
+				}
+			}
+
 			if let Some(monitor) = self.get_monitor_with_focus() {
-				let index = Some(monitor.index);
-				self.dash_state.summary_window_list.state.select(index);
+				let selected_logfile = monitor.logfile.clone();
+				if let Some(node_index) = self.dash_state.logfile_names_sorted.iter().position(|s| s == selected_logfile.as_str()) {
+					self.dash_state.summary_window_rows.state.select(Some(node_index));
+				}
 			}
 		}
 	}
 
+		// TODO this regenerates every line. May be worth just updating the line for the updated node/monitor
+		// Needs to be on the app to manage focus for DashSummary and DashNode through sorting of summary table
+		pub fn update_summary_window(&mut self) {
+			let current_selection = self.dash_state.summary_window_rows.state.selected();
+
+			self.dash_state.summary_window_rows = StatefulList::new();
+
+			// TODO could avoid this repeated copy by ensuring both are modified at the same time
+			self.dash_state.logfile_names_sorted = self.dash_state.logfile_names
+				.iter()
+				.map(|f| f.clone())
+				.collect();
+
+			crate::custom::ui_summary_table::sort_nodes_by_column(&mut self.dash_state, &mut self.monitors);
+
+			for i in 0..self.dash_state.logfile_names_sorted.len() {
+				let filepath = self.dash_state.logfile_names_sorted[i].clone();
+				if let Some(monitor) = self.monitors.get_mut(&filepath) {
+					if !monitor.is_debug_dashboard_log {
+						monitor.metrics.update_node_status_string();
+						let node_summary = crate::custom::ui_summary_table::format_table_row(monitor);
+						self.append_to_summary_window(&node_summary);
+					}
+				}
+			}
+
+			self.dash_state.summary_window_rows.state.select(current_selection);
+		}
+
+		fn append_to_summary_window(&mut self, text: &str){
+			self.dash_state.summary_window_rows.items.push(text.to_string());
+
+			let len = self.dash_state.summary_window_rows.items.len();
+
+			if len > self.dash_state.max_summary_window {
+				self.dash_state.summary_window_rows.items = self.dash_state
+					.summary_window_rows
+					.items
+					.split_off(len - self.dash_state.max_summary_window);
+			} else {
+				self.dash_state.summary_window_rows.state.select(Some(len - 1));
+			}
+
+		}
+
 	pub fn toggle_logfile_area(&mut self) {
 		self.dash_state.node_logfile_visible = !self.dash_state.node_logfile_visible;
 	}
@@ -436,7 +507,7 @@ fn exit_with_usage(reason: &str) -> Result<App, std::io::Error> {
 	return Err(Error::new(ErrorKind::Other, reason));
 }
 
-use fs2::{statvfs, FsStats};
+use fs2::FsStats;
 
 const NODE_INACTIVITY_TIMEOUT_S: i64 = 20;	// Seconds with no log message before node becomes 'inactive'
 
@@ -457,24 +528,24 @@ use std::sync::atomic::{AtomicUsize, Ordering};
 static NEXT_MONITOR: AtomicUsize = AtomicUsize::new(0);
 
 impl LogMonitor {
-	pub fn new(opt: &Opt, f: String, max_lines: usize) -> LogMonitor {
+	pub fn new(opt: &Opt, logfile_path: String, max_lines: usize) -> LogMonitor {
 		let index = NEXT_MONITOR.fetch_add(1, Ordering::Relaxed);
 
 		let mut is_debug_dashboard_log = false;
 		if let Some(debug_logfile) = &*DEBUG_LOGFILE.lock().unwrap() {
 			if let Some(debug_logfile_path) = debug_logfile.path().to_str() {
-				is_debug_dashboard_log = f.eq(debug_logfile_path);
+				is_debug_dashboard_log = logfile_path.eq(debug_logfile_path);
 			}
 		}
 
-		let mut chunk_store_pathbuf = PathBuf::from(&f);
+		let mut chunk_store_pathbuf = PathBuf::from(&logfile_path);
 		if chunk_store_pathbuf.pop() {
 			chunk_store_pathbuf.push("chunkdb")
 		}
 
 		LogMonitor {
 			index,
-			logfile: f,
+			logfile: logfile_path,
 			max_content: max_lines,
 			chunk_store_fsstats: None,
 			chunk_store_pathbuf,
@@ -488,12 +559,12 @@ impl LogMonitor {
 
 	pub fn is_node(&self) -> bool { return !self.is_debug_dashboard_log; }
 
-	pub fn update_chunk_store_fsstats(&mut self) {
-		self.chunk_store_fsstats = match statvfs(&self.chunk_store_pathbuf) {
-			Ok(fsstats) => Some(fsstats),
-			Err(_) => None,
-		};
-	}
+	// pub fn update_chunk_store_fsstats(&mut self) {
+	// 	self.chunk_store_fsstats = match statvfs(&self.chunk_store_pathbuf) {
+	// 		Ok(fsstats) => Some(fsstats),
+	// 		Err(_) => None,
+	// 	};
+	// }
 
 	pub fn load_logfile(&mut self, dash_state: &mut DashState) -> std::io::Result<()> {
 		use std::io::{BufRead, BufReader};
@@ -504,7 +575,7 @@ impl LogMonitor {
 			Err(_e) => return Ok(()), // It's ok for a logfile not to exist yet
 		};
 
-		self.update_chunk_store_fsstats();
+		// self.update_chunk_store_fsstats();
 		let f = BufReader::new(f);
 
 		for line in f.lines() {
@@ -615,6 +686,8 @@ pub struct NodeMetrics {
 	pub node_started: Option<DateTime<Utc>>,
 	pub running_message: Option<String>,
 	pub running_version: Option<String>,
+	pub node_process_id: Option<u64>,
+	pub node_peer_id: Option<String>,
 	pub category_count: HashMap<String, usize>,
 	pub activity_history: Vec<ActivityEntry>,
 
@@ -622,6 +695,7 @@ pub struct NodeMetrics {
 
 	pub entry_metadata: Option<LogMeta>,
 	pub node_status: NodeStatus,
+	pub node_status_string: String,
 	pub node_inactive: bool,
 
 	pub activity_gets: MmmStat,
@@ -664,6 +738,8 @@ impl NodeMetrics {
 			node_started: None,
 			running_message: None,
 			running_version: None,
+			node_process_id: None,
+			node_peer_id: None,
 
 			// Logfile entries
 			activity_history: Vec::<ActivityEntry>::new(),
@@ -685,6 +761,7 @@ impl NodeMetrics {
 
 			// State (node)
 			node_status: NodeStatus::Stopped,
+			node_status_string: String::from(""),
 			node_inactive: false,
 
 			// State (network)
@@ -723,7 +800,7 @@ impl NodeMetrics {
 
 	pub fn is_node_active(&self) -> bool {return !self.node_inactive;}
 
-	pub fn get_node_status_string(&mut self) -> String {
+	pub fn update_node_status_string(&mut self) {
 		let node_inactive_timeout = Duration::seconds(NODE_INACTIVITY_TIMEOUT_S);
 
 		let mut node_status_string = node_status_as_string(&self.node_status);
@@ -738,7 +815,7 @@ impl NodeMetrics {
 			}
 		}
 
-		return node_status_string;
+		self.node_status_string = node_status_string;
 	}
 
 	fn reset_metrics(&mut self) {
@@ -810,6 +887,21 @@ impl NodeMetrics {
 			return true;
 		}
 
+		let process_id_prefix = "Node (PID: ";
+		if line.contains(&process_id_prefix) {
+			self.node_process_id = self.parse_u64(process_id_prefix, line);
+			let process_id = match &self.node_process_id {
+				Some(process_id) => process_id.to_string(),
+				None => String::from("unknown")
+			};
+
+			if let Some(peer_id) = self.parse_string("PeerId: ", line) {
+				self.parser_output = format!("Node pid: {} peer_id: {}", String::from(process_id.clone()), peer_id);
+				self.node_peer_id = Some(peer_id);
+			}
+			return true;
+		}
+
 		false
 	}
 
@@ -887,6 +979,26 @@ impl NodeMetrics {
 		return false;
 	}
 
+	///! Update data metrics from a handler response logfile entry
+	///! Returns true if the line has been processed and can be discarded
+	fn parse_string(&mut self, prefix: &str, line: &String) -> Option<String> {
+		let mut string = "";
+		if let Some(mut string_start) = line.find(prefix) {
+			string_start += prefix.len();
+
+			if let Some(string_end) = line[string_start..].find("\"") {
+				string = line.as_str()[string_start..string_start + string_end].as_ref()
+				} else {
+				string = line.as_str()[string_start..].as_ref()
+			}
+			if string.is_empty() {
+				self.parser_output = format!("failed to parse string after {} in: {}", prefix, line);
+			}
+		};
+
+		if string.len() > 0 { Some(String::from(string)) } else { None }
+	}
+
 	///! Capture state updates from a logfile entry
 	///! Returns true if the line has been processed and can be discarded
 	fn parse_states(&mut self, line: &String, entry_metadata: &LogMeta) -> bool {
@@ -1237,15 +1349,19 @@ pub enum DashViewMain {
 pub struct DashState {
 	pub main_view: DashViewMain,
 	pub logfile_names: Vec<String>,
+	pub logfile_names_sorted: Vec<String>,
+	pub logfile_names_sorted_ascending: bool,
+
 	pub active_timescale: usize,
 	pub node_logfile_visible: bool,
 	pub dash_node_focus: String,
     pub mmm_ui_mode:   MinMeanMax,
     pub top_timeline: usize,  // Timeline to show at top of UI
 
-	pub summary_window_heading: String,
-	pub summary_window_list: StatefulList<String>,
-	pub summary_list_monitor_positions: Vec<String>,
+	pub summary_window_heading: String,	// TODO delete in favour of...
+	pub summary_window_headings: StatefulList<String>,
+	pub summary_window_heading_selected: usize,
+	pub summary_window_rows: StatefulList<String>,
 	max_summary_window: usize,
 
 	pub help_status: StatefulList<String>,
@@ -1260,9 +1376,12 @@ pub struct DashState {
 impl DashState {
 	pub fn new() -> DashState {
 
-		DashState {
+		let mut new_dash = DashState {
 			main_view: DashViewMain::DashSummary,
-			logfile_names: Vec::<String>::new(),
+			logfile_names: Vec::<String>::new(),				// Ordered in sync with LogMonitor.index?
+			logfile_names_sorted: Vec::<String>::new(),	// Sorted by column
+			logfile_names_sorted_ascending: true,
+
 			active_timescale: 0,
 			node_logfile_visible: true,
 			dash_node_focus: String::new(),
@@ -1270,8 +1389,9 @@ impl DashState {
             top_timeline: 0,
 
 			summary_window_heading: String::from(""),
-			summary_window_list: StatefulList::new(),
-			summary_list_monitor_positions: Vec::new(),
+			summary_window_headings: StatefulList::new(),
+			summary_window_heading_selected: 0,
+			summary_window_rows: StatefulList::new(),
 			max_summary_window: 1000,
 
 			help_status: StatefulList::with_items(vec![]),
@@ -1280,67 +1400,9 @@ impl DashState {
 			debug_window_has_focus: false,
 			debug_window_list: StatefulList::new(),
 			max_debug_window: 100,
-		}
-	}
-
-	// TODO this regenerates every line. May be worth just updating the line for the updated node/monitor
-	pub fn update_summary_window(&mut self, monitors: &mut HashMap<String, LogMonitor>) {
-		let current_selection = self.summary_window_list.state.selected();
-		self.summary_window_list = StatefulList::new();
-
-		let earnings_heading = format!("Earned ({})", crate::custom::app_timelines::EARNINGS_UNITS_TEXT);
-
-		self.summary_window_heading = format!("{:>4} {:>15}{:>12} {:>11} {:>11} {:>11} {:>11} {:>11} {:>24}",
-			String::from("Node"),
-			earnings_heading,
-			String::from("StoreCost"),
-			String::from("PUTS"),
-			String::from("GETS"),
-			String::from("Errors"),
-			String::from("Connections"),
-			String::from("MB RAM"),
-			String::from("Status"),
-		);
-
-		for i in 0..self.logfile_names.len() {
-			let filepath = self.logfile_names[i].clone();
-			if let Some(monitor) = monitors.get_mut(&filepath) {
-				if !monitor.is_debug_dashboard_log {
-					let node_status_string = monitor.metrics.get_node_status_string();
-					let node_summary = format!("{:>4} {:>15}{:>12} {:>11} {:>11} {:>11} {:>11} {:>11} {:>24}",
-						monitor.index + 1,
-						monitor.metrics.storage_payments.total.to_string(),
-						monitor.metrics.storage_cost.most_recent,
-						monitor.metrics.activity_puts.total,
-						monitor.metrics.activity_gets.total,
-						monitor.metrics.activity_errors.total,
-						monitor.metrics.peers_connected.most_recent,
-						monitor.metrics.memory_used_mb.most_recent,
-						node_status_string
-					);
-					self.append_to_summary_window(&node_summary);
-					self.summary_list_monitor_positions.push(filepath.clone());
-				}
-			}
-		}
-
-		self.summary_window_list.state.select(current_selection);
-	}
-
-	fn append_to_summary_window(&mut self, text: &str){
-		self.summary_window_list.items.push(text.to_string());
-
-		let len = self.summary_window_list.items.len();
-
-		if len > self.max_summary_window {
-			self.summary_window_list.items = self
-				.summary_window_list
-				.items
-				.split_off(len - self.max_summary_window);
-		} else {
-			self.summary_window_list.state.select(Some(len - 1));
-		}
-
+		};
+		crate::custom::ui_summary_table::initialise_summary_headings(&mut new_dash);
+		new_dash
 	}
 
 	pub fn _debug_window(&mut self, text: &str) {
@@ -1403,8 +1465,9 @@ pub fn set_main_view(view: DashViewMain, app: &mut App) {
 
 pub fn save_focus(app: &mut App) {
 	match app.dash_state.main_view {
-		DashViewMain::DashSummary => {} // TODO
-		DashViewMain::DashHelp => {} // TODO
+		DashViewMain::DashHelp => {}
+
+		DashViewMain::DashSummary|
 		DashViewMain::DashNode => {
 			if let Some(focus) = app.get_logfile_with_focus() {
 				app.dash_state.dash_node_focus = focus;
@@ -1416,8 +1479,9 @@ pub fn save_focus(app: &mut App) {
 
 pub fn restore_focus(app: &mut App) {
 	match app.dash_state.main_view {
-		DashViewMain::DashSummary => {} // TODO
-		DashViewMain::DashHelp => {} // TODO
+		DashViewMain::DashHelp => {}
+
+		DashViewMain::DashSummary|
 		DashViewMain::DashNode => {
 			app.set_logfile_with_focus(app.dash_state.dash_node_focus.clone())
 		}
